.. _tensor-tensor:

Tensor
======

.. module:: sympy.tensor.tensor

.. autoclass:: TensorIndexType
   :members:

.. autoclass:: TensorIndex
   :members:

.. autoclass:: TensorHead
   :members:

.. autofunction:: tensor_heads

.. autoclass:: TensExpr
   :members:

.. autoclass:: TensAdd
   :members:

.. autoclass:: TensMul
   :members:

.. autofunction:: canon_bp

.. autofunction:: riemann_cyclic_replace

.. autofunction:: riemann_cyclic

.. autoclass:: TensorSymmetry
   :members:

.. autofunction:: tensorsymmetry

.. autoclass:: TensorType
   :members:

.. autoclass:: _TensorManager
   :members:
